---
name: Bug report
about: Report an issue to help us improve
title: ""
labels: bug
assignees: ""
---

## Bug description

<!--- A clear and concise description of what the bug is. -->

## Steps to reproduce

<!--- Steps to reproduce the behavior. -->

1.
2.
3.

## Expected behavior

<!--- A clear and concise description of what you expected to happen. -->

## Additional context

<!---Add any other context or screenshots about the problem here.-->

<!---If relevant, please include the browser you are using, and the package versions in your environment (pip list).-->
